/**
  Programa para leer los votos de 1 ciudadano DE UNA CIRCUNSCRIPCION en unas elecciones generales. 
  El programa almacena cuantos votos se asignan a cada partido tanto para el congreso como para el senado.
**/

#include <iostream> // cin y cout
#include <string.h> // strcpy

#define N_PARTIDOS 11
#define MAX_NOMBRE_PARTIDO 15

// vector asociacion de texto representando nombre de partido con indices del vector. De 0 a 10 
const char *partidos[N_PARTIDOS] = {"PP", "PSOE", "IU", "CiU", "PNV", "UPyD", "BNG", "CC-NC-PNC", "ERC-RI", "Voto en blanco", "Voto nulo"};

// tipo estructura que permite almacenar 2 enteros. El primero se llama congreso y el segundo senado y
// guarda el voto emitido por cada ciudadano. OJO estructura homogeneea
struct voto {
  int congreso;
  struct {
    int senado1, senado2;
  } sen;
};

// tipo estructura que permite almacenar los datos asociados a cada partido.
struct resultado {
  char nombre[MAX_NOMBRE_PARTIDO]; // indice de nombre del partido en el array "partido"
  int num_votos_con; // nmero de votos recibidos para el congreso
  int num_votos_sen; // numero de votos recibidos para el senado       
};

using namespace std;

int main(void) {
struct voto v; // variable de tipo estructura para guardar los votos de cada ciudadano
struct resultado p[N_PARTIDOS]; // array para guardar los resultados de cada partido
int conf; // variable para confirmar
int i, j, k; // variable para bucles
  
  // inicializacin de array para los partidos
  for (i = 0; i < N_PARTIDOS; i++) {
    strcpy(p[i].nombre, partidos[i]); 
    p[i].num_votos_con = 0;
    p[i].num_votos_sen = 0;   
  } // for
    
  do {
            
    // Presentar en pantalla los partidos a votar para el congreso
    cout << "Partidos que se presentan:" << endl;
    for (i = 0; i < N_PARTIDOS; i++)
      cout << i+1 << ".- " << partidos[i] << endl;
    // Solicitar indice entero asociado a cada partido 
    do {
      cout << "Ciudadano introduzca su voto para el congreso (1 - " << N_PARTIDOS << "): ";
      cin >> v.congreso;
    } while (v.congreso < 1 || v.congreso > N_PARTIDOS);

    // Solicitar indice entero asociado a cada senador
    do {
      std::cout << "Ciudadano introduzca su voto 1 para el senado (1 - " << N_PARTIDOS << "): ";
      std::cin >> v.sen.senado1;
    } while (v.sen.senado1 < 1 || v.sen.senado1 > N_PARTIDOS);

    do {
      std::cout << "Ciudadano introduzca su voto 2 para el senado (1 - " << N_PARTIDOS << "): ";
      std::cin >> v.sen.senado2;
    } while (v.sen.senado2 < 1 || v.sen.senado2 > N_PARTIDOS);

    cout << "El ciudadano ha votado: " << partidos[v.congreso-1] << " al congreso. "; 
    cout << "Senador 1  del partido " << partidos[v.sen.senado1-1] << endl;
    cout << "Senador 2  del partido " << partidos[v.sen.senado2-1] << endl;
    cout << "Introduce 0 para confirmar: ";
    cin >> conf;
  } while (conf != 0);
      
  // almacenar votos en los partidos correspondientes
  (p[v.congreso-1].num_votos_con)++;
  (p[v.sen.senado1-1].num_votos_sen)++;
  (p[v.sen.senado2-1].num_votos_sen)++;
  
  // Imprimir resultados de partidos polticos
  cout << "Partido: " << p[v.congreso-1].nombre << endl << "Numero de votos Congreso: " << p[v.congreso-1].num_votos_con << endl;
  cout << "Partido: " << p[v.sen.senado1-1].nombre << endl << "Numero de votos Senado: " << p[v.sen.senado1-1].num_votos_sen << endl;
  cout << "Partido: " << p[v.sen.senado2-1].nombre << endl << "Numero de votos Senado: " << p[v.sen.senado2-1].num_votos_sen << endl;        
  cin >> conf;
} /* main */
